.TH LESS l
.SH NAME
less \- opposite of more
.SH SYNOPSIS
.B "less [\-cdepstwmMqQuU] [\-h\fIn\fB] [\-b[fp]\fIn\fB] [\-x\fIn\fB] [\-[z]\fIn\fB] [+\fIcmd\fB] [\fIname\fB] ..."
.SH DESCRIPTION
\fILess\fR is a program similar to \fImore\fR(1), but which allows backwards
movement in the file as well as forward movement.  Also, \fIless\fR does not
have to read the entire input file before starting, so with large input
files it starts up faster than text editors like \fIvi\fR(1).  \fILess\fR
uses termcap, so it can run on a variety of terminals.  There is even
limited support for hardcopy terminals.  (On a hardcopy terminal, lines
which should be printed at the top of the screen are prefixed with an
up-arrow.)
.PP
Commands are based on both \fImore\fR and \fIvi\fR.  Commands may be
preceeded by a decimal number, called N in the descriptions below.  The
number is used by some commands, as indicated.
.SH COMMANDS
.IP \fBh\fR
Help: display a summary of these commands.  If you forget all the other
commands, remember this one.
.PP
.IP \fBSPACE\fR
Scroll forward N lines, default one window (see option \fB\-z\fR below).  If
N is more than the screen size, only one screenful is displayed.
.PP
.IP \fBf\fR
Same as \fBSPACE\fR.
.PP
.IP \fBb\fR
Scroll backward N lines, default one window (see option \fB\-z\fR below).
If N is more than the screen size, only one screenful is displayed.
.PP
.IP \fBRETURN\fR
Scroll forward N lines, default 1.  If N is more than the screen size, the
entire N lines are displayed.
.PP
.IP \fBe\fR
Same as \fBRETURN\fR.
.PP
.IP \fBj\fR
Also the same as \fBRETURN\fR.
.PP
.IP \fBy\fR
Scroll backward N lines, default 1.  If N is more than the screen size, the
entire N lines are displayed.
.IP \fBk\fR
Same as \fBy\fR.
.PP
.IP \fBd\fR
Scroll forward N lines, default 10.  If N is specified, it becomes the new
default for all \fBd\fR and \fBu\fR commands.
.PP
.IP \fBu\fR
Scroll backward N lines, default 10.  If N is specified, it becomes the new
default for all \fBd\fR and \fBu\fR commands.
.PP
.IP \fBr\fR
Repaint the screen.
.PP
.IP \fBR\fR
Repaint the screen, discarding any buffered input.  Useful if the file is
changing while it is being viewed.
.PP
.IP \fBg\fR
Go to line N in the file, default 1 (beginning of file).  (Warning: this may
be slow if N is large.)
.PP
.IP \fBG\fR
Go to line N in the file, default the end of the file.  (Warning: this may
be slow if standard input, rather than a file, is being read.)
.PP
.IP \fBp\fR
Go to a position N percent into the file.  N should be between 0 and 100.
(This is possible if standard input is being read, but only if \fIless\fR
has already read to the end of the file.  It is always fast, but not always
useful.)
.PP
.IP \fB%\fR
Same as \fBp\fR.
.PP
.IP \fBm\fIl\fR
Followed by any lowercase letter, \fIl\fR, marks the current position with
that letter.
.PP
.IP \fB'\fIl\fR
Followed by any lowercase letter, \fIl\fR, returns to the position which was
previously marked with that letter.  All marks are lost when a new file is
examined.
.PP
.IP \fB/pattern\fR
Search forward in the file for the N-th occurence of the \fIpattern\fR.  N
defaults to 1.  The \fIpattern\fR is a regular expression, as recognized by
\fIed\fR.  The search starts at the second line displayed (but see the
\fB\-t\fR option, which changes this).
.PP
.IP \fB?pattern\fR
Search backward in the file for the N-th occurence of the \fIpattern\fR.
The search starts at the line immediately before the top line displayed.
.PP
.IP \fBn\fR
Repeat previous search, for N-th occurence of the last \fIpattern\fR.
.PP
.IP \fBE\fR\ \fI[filename]\fR
Examine a new file.  If the \fIfilename\fR is missing, the "current" file
(see the \fBN\fR and \fBP\fR commands below) from the list of files in the
command line is re-examined.
.PP
.IP \fBN\fR
Examine the next file (from the list of files given in the command line).
If a number N is specified (not to be confused with the command \fBN\fR),
the N-th next file is examined.
.PP
.IP \fBP\fR
Examine the previous file.  If a number N is specified, the N-th previous
file is examined.
.PP
.IP \fB=\fR
Prints the name of the file being viewed and the byte offset of the bottom
line being displayed.  If possible, it also prints the length of the file
and the percent of the file above the last displayed line.
.PP
.IP \fB\-\fR
Followed by one of the command line option letters (see below), this will
toggle the setting of that option and print a message describing the new
setting.
.PP
.IP \fBV\fR
Prints the version number of \fIless\fR being run.
.PP
.IP \fBq\fR
Exits \fIless\fR.
.PP
The following two commands may or may not be valid, depending on your
particular installation.
.PP
.IP \fBv\fR
Invokes an editor to edit the current file being viewed.  The editor is
taken from the environment variable \fBEDITOR\fR, or defaults to \fIvi\fR.
.PP
.IP \fB!\fR\ \fIshell-command\fR
Invokes a shell to run the
.I shell-command
given.
.PP
.SH OPTIONS
Command line options are described below.  Options are also taken from the
environment variable \fBLESS\fR.  (The environment variable is parsed before
the command line, so command line options override the \fBLESS\fR environment
variable.  Options may be changed while \fIless\fR is running via the
\fB"\-"\fR command.)  For example, if you like more-style prompting, to
avoid typing \fBless\ \-m\ ...\fR each time \fIless\fR is invoked, you might
tell \fIcsh\fR:
.sp
.B setenv LESS m
.sp
or if you use \fIsh\fR:
.sp
.B LESS=m; export LESS
.IP \fB\-s\fR
The \fB\-s\fR flag causes consecutive blank lines to be squeezed into a
single blank line.  This is useful when viewing \fInroff\fR output.
.IP \fB\-t\fR
Normally, forward searches start just after the top displayed line (that is,
at the second displayed line).  Thus forward searches include the currently
displayed screen.  The \fB\-t\fR command line option causes forward searches
to start just after the bottom line displayed, thus skipping the currently
displayed screen.
.IP \fB\-m\fR
Normally, \fIless\fR prompts with a colon.  The \fB\-m\fR command line
option causes \fIless\fR to prompt verbosely like \fImore\fR, printing the
file name and percent into the file.
.IP \fB\-M\fR
The \fB\-M\fR command line option causes \fIless\fR to prompt even more
verbosely than \fImore\fR.
.IP \fB\-q\fR
Normally, if an attempt is made to scroll past the end of the file or before
the beginning of the file, the terminal bell is rung to indicate this fact.
The \fB\-q\fR command line option tells \fIless\fR not to ring the bell at
such times.  If the terminal has a "visual bell", it is used instead.
.IP \fB\-Q\fR
Even if \fB\-q\fR is given, \fIless\fR will ring the bell on certain other
errors, such as typing an invalid character.  The \fB\-Q\fR command line
option tells \fIless\fR to be quiet all the time; that is, never ring the
terminal bell.  If the terminal has a "visual bell", it is used instead.
.IP \fB\-e\fR
Normally the only way to exit less is via the "q" command.  The \fB\-e\fR
command line option tells less to automatically exit the second time it
reaches end-of-file.
.IP \fB\-u\fR
If the \fB\-u\fR command line option is given, backspaces are treated as
printable characters; that is, they are sent to the terminal when they
appear in the input.
.IP \fB\-U\fR
If the \fB\-U\fR command line option is given, backspaces are printed as the
two character sequence "^H".  If neither \fB\-u\fR nor \fB\-U\fR is given,
backspaces which appear adjacent to an underscore character or sequences of
a character interleaved with backspaces are treated specially:  the
underlined or boldfaced text is displayed using the terminal's hardware
capability.  Note that the \fB\-v\fR option below superceeds both \fB\-u\fR
and \fB\-U\fR.
.IP \fB\-w\fR
Normally, \fIless\fR uses a tilde character to represent lines past the end
of the file.  The \fB\-w\fR option causes blank lines to be used instead.
.IP \fB\-d\fR
Normally, \fIless\fR will complain if the terminal is dumb; that is, lacks
some important capability, such as the ability to clear the screen or scroll
backwards.  The \fB\-d\fR flag suppresses this complaint (but does not
otherwise change the behavior of the program on a dumb terminal).
.IP \fB\-p\fR
Normally, \fIless\fR will repaint the screen by scrolling from the bottom of
the screen.  If the \fB\-p\fR flag is set, when \fIless\fR needs to change
the entire display, it will clear the screen and paint from the top line
down.
.IP \fB\-h\fIn\fR
Normally, \fIless\fR will scroll backwards when backwards movement is
necessary.  The \fB\-h\fR option specifies a maximum number of lines to
scroll backwards.  If it is necessary to move backwards more than this many
lines, the screen is repainted in a forward direction.  (If the terminal
does not have the ability to scroll backwards, \fB\-h\fI0\fR is implied.)
.IP \fB\-[z]\fIn\fR
When given a backwards or forwards window command, \fIless\fR will by
default scroll backwards or forwards one screenful of lines.  The \fB\-z\fR
option changes the default scrolling window size to \fIn\fR lines.  If
\fIn\fR is greater than the screen size, the scrolling window size will be
set to one screenful.  Note that the \fBz\fR is optional for compatibility
with more.
.IP \fB\-x\fR
The \fB\-x\fR command line option sets tab stops every \fIn\fR positions.
The default for \fIn\fR is 8.
.IP \fB\-b[fp]\fIn\fR
The \fB\-b\fR command line option tells \fIless\fR to use a non-standard
buffer size.  There are two standard (default) buffer sizes, one is used
when a file is being read and the other when a pipe (standard input) is
being read.  The current defaults are 5 buffers for files and 12 for pipes.
(Buffers are 1024 bytes.)  The number \fIn\fR specifies a different number
of buffers to use.  The \fB\-b\fR may be followed by \fBf\fR, in which case
only the file default is changed, or by \fBp\fR in which case only the pipe
default is changed.  Otherwise, both are changed.
.IP \fB\-c\fR
Normally, when data is read by \fIless\fR, it is scanned to ensure that bit
7 (the high order bit) is turned off in each byte read, and to ensure that
there are no null (zero) bytes in the data (null bytes are turned into "@"
characters).  If the data is known to be "clean", the \fB\-c\fR command line
option will tell \fIless\fR to skip this checking, causing an imperceptible
speed improvement.  (However, if the data is not "clean", unpredicatable
results may occur.)
.IP \fB\-v\fR
The \fB\-v\fR option tells less to print non-printing characters in a
visible way ala \fIcat\fR(1).  Control characters are printed as ^X (the
delete character (octal 0177) is printed as ^?).  Characters with the 0200
bit set are printed as M- followed by the character represented by the low
order seven bits.
.IP \fB+\fIcommand\fR
If a command line option begins with \fB+\fR, the remainder of that option
is taken to be an initial command to \fIless\fR.  For example, \fB+\fIG\fR
tells \fIless\fR to start at the end of the file rather than the beginning,
and \fB+\fI/xyz\fR tells it to start at the first occurence of \fIxyz\fR in
the file.  As a special case, \fB+\fI<number>\fR acts like
\fB+\fI<number>g\fR; that is, it starts the display at the specified line
number (however, see the caveat under the \fBg\fR command above).  If the
option starts with \fB++\fR, the initial command applies to every file being
viewed, not just the first one.
.SH BUGS
When used on standard input (rather than a file), you can move backwards
only a finite amount, corresponding to that portion of the file which is
still buffered.
